@@ -40,9 +40,10 @@
  * @param[out] ii_info  Pointer to ImageInfo object
  * @return     none
  */
+/*----------------------------------------------------------------------------*/
 static int  compare_imageitems (const ImageInfo *ii_info1,
                                 const ImageInfo *ii_info2);
-/*----------------------------------------------------------------------------*/
+
 static void imageinfo_init     (ImageInfo       *ii_info);
 /*----------------------------------------------------------------------------*/
 /**
@@ -65,8 +66,8 @@ imageinfo_init (ImageInfo *ii_info)
     ii_info->s_file_name    = NULL;
     ii_info->s_file_path    = NULL;
     ii_info->s_width_height = NULL;
-    ii_info->ui_height      = 0;
-    ii_info->ui_width       = 0;
+    ii_info->i_height       = 0;
+    ii_info->i_width        = 0;
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -98,7 +99,7 @@ imageinfo_new_from_file (const char *s_fname)
     char      *s_p     = NULL; /* Pointer to right position of / */
     int        i_w     = 0;    /* Image width */
     int        i_h     = 0;    /* Image height */
-    
+
     if (s_fname == NULL)
         return NULL;
 
@@ -115,8 +116,10 @@ imageinfo_new_from_file (const char *s_fname)
     else {
         s_p++;
         imageinfo_set_file_name (ii_info, s_p);
+
         s_path = str_ndup (s_fname, s_p - s_fname);
         imageinfo_set_file_path (ii_info, s_path);
+
         free (s_path);
     }
 
@@ -127,6 +130,8 @@ imageinfo_new_from_file (const char *s_fname)
     imageinfo_set_width (ii_info, i_w);
     imageinfo_set_height (ii_info, i_h);
 
+    imageinfo_set_wxh (ii_info, i_w, i_h);
+
     return ii_info;
 }
 /*----------------------------------------------------------------------------*/
@@ -166,11 +171,12 @@ GSList * imageinfo_remove_duplicates (GSList *gsl_iinfo)
         while (gsl_nxt) {
 
             gsl_act = gsl_nxt;
-
             gsl_nxt = gsl_nxt->next;
 
             if (compare_imageitems (gsl_itr->data, gsl_act->data) == 0) {
+
                 gsl_iinfo = g_slist_remove_link (gsl_iinfo, gsl_act);
+
                 imageinfo_free (gsl_act->data);
             }
         }
@@ -191,9 +197,12 @@ file_paths_to_imageinfo (GSList *gsl_files1)
     gsl_files = gsl_files1;
 
     while (gsl_files != NULL) {
+
         ii_info = imageinfo_new_from_file ((char *) gsl_files->data);
+
         if (imageinfo_get_height (ii_info) > 0)
             gsl_iinfo = g_slist_append (gsl_iinfo, ii_info);
+
         gsl_files = gsl_files->next;
     }
     return gsl_iinfo;
@@ -203,7 +212,7 @@ file_paths_to_imageinfo (GSList *gsl_files1)
  * @brief  Get image info of files in list and store it in FList.
  */
 GSList *
-flist_to_imageinfo (FList *fl_files)
+flist_to_imageinfo (const FList *fl_files)
 {
     ImageInfo  *ii_info;
     GSList     *gsl_iinfo = NULL; /* Result ImageInfo list */
@@ -214,8 +223,10 @@ flist_to_imageinfo (FList *fl_files)
     ui_cnt = flist_get_len (fl_files);
 
     for (i = 0; i < ui_cnt; ++i) {
+
         s_fn = flist_get_data (fl_files, i);
         ii_info = imageinfo_new_from_file (s_fn);
+
         if (imageinfo_get_height (ii_info) > 0)
             gsl_iinfo = g_slist_append (gsl_iinfo, ii_info);
     }
@@ -235,8 +246,11 @@ imageinfo_append_to_flist (GSList *gsl_iinfo1,
     gsl_iinfo = gsl_iinfo1;
 
     while (gsl_iinfo != NULL) {
+
         ii_info = gsl_iinfo->data;
+
         flist_insert_data (fl_files, imageinfo_get_full_name (ii_info));
+
         gsl_iinfo = gsl_iinfo->next;
     }
     return 0;
@@ -249,6 +263,9 @@ void
 imageinfo_set_full_name (ImageInfo  *ii_info, 
                          const char *s_name)
 {
+    if (ii_info->s_full_path != NULL)
+        free (ii_info->s_full_path);
+
     ii_info->s_full_path = str_dup (s_name);
 }
 /*----------------------------------------------------------------------------*/
@@ -268,6 +285,9 @@ void
 imageinfo_set_file_name (ImageInfo  *ii_info, 
                          const char *s_name)
 {
+    if (ii_info->s_file_name != NULL)
+        free (ii_info->s_file_name);
+
     ii_info->s_file_name = str_dup (s_name);
 }
 /*----------------------------------------------------------------------------*/
@@ -287,6 +307,9 @@ void
 imageinfo_set_file_path (ImageInfo  *ii_info, 
                          const char *s_name)
 {
+    if (ii_info->s_file_path != NULL)
+        free (ii_info->s_file_path);
+
     ii_info->s_file_path = str_dup (s_name);
 }
 /*----------------------------------------------------------------------------*/
@@ -303,10 +326,10 @@ imageinfo_get_file_path (const ImageInfo *ii_info)
  * @brief  Set image width information
  */
 void
-imageinfo_set_width (ImageInfo  *ii_info, 
-                     uint16_t    ui_val)
+imageinfo_set_width (ImageInfo *ii_info, 
+                     const int  i_val)
 {
-    ii_info->ui_width = ui_val; 
+    ii_info->i_width = i_val; 
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -315,17 +338,17 @@ imageinfo_set_width (ImageInfo  *ii_info,
 int
 imageinfo_get_width (const ImageInfo *ii_info)
 {
-    return ii_info->ui_width;
+    return ii_info->i_width;
 }
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Set image height information
  */
 void
-imageinfo_set_height (ImageInfo  *ii_info, 
-                      uint16_t    ui_val)
+imageinfo_set_height (ImageInfo *ii_info, 
+                      const int  i_val)
 {
-    ii_info->ui_height = ui_val; 
+    ii_info->i_height = i_val; 
 }
 /*----------------------------------------------------------------------------*/
 /**
@@ -334,27 +357,35 @@ imageinfo_set_height (ImageInfo  *ii_info,
 int
 imageinfo_get_height (const ImageInfo *ii_info)
 {
-    return ii_info->ui_height;
+    return ii_info->i_height;
+}
+/*----------------------------------------------------------------------------*/
+/**
+ * @brief  Get string with image dimensions (width x height)
+ */
+void
+imageinfo_set_wxh (ImageInfo *ii_info,
+                   const int  i_w,
+                   const int  i_h)
+{
+    char s_tmp[40]; /* Temp string, I think it is long enough */
+
+    memset (s_tmp, 0, sizeof(s_tmp));
+
+    sprintf (s_tmp, "%dx%d", i_w, i_h);
+
+    create_resize ((void**) &ii_info->s_width_height, strlen (s_tmp)+1,
+                   sizeof (char));
+
+    strcpy (ii_info->s_width_height, s_tmp);
 }
 /*----------------------------------------------------------------------------*/
 /**
  * @brief  Get string with image dimensions (width x height)
  */
 const char *
-imageinfo_get_wxh (ImageInfo *ii_info)
+imageinfo_get_wxh (const ImageInfo *ii_info)
 {
-    char s_tmp[40]; /* Temp string, I think it is long enough */
-
-    memset (s_tmp, 0, sizeof(s_tmp));
-
-    sprintf (s_tmp, "%dx%d",
-             imageinfo_get_width (ii_info), imageinfo_get_height (ii_info));
-
-    create_resize ((void**) &ii_info->s_width_height, strlen (s_tmp)+1,
-                   sizeof (char));
-
-    strcpy (ii_info->s_width_height, s_tmp);
-
     return (const char*) ii_info->s_width_height;       
 }
 /*----------------------------------------------------------------------------*/
